@@ -5,7 +5,7 @@ from Cython.Build import cythonize
 
 setup(
     name="NBCPU-Pipeline",
-    ext_modules=cythonize("*.py"),
+    ext_modules=cythonize("*.pyx"),
     description="Parallel Threading Utilizing Common CPU Procedures",
     author="Alex",
     author_email="obfuscate@riseup.net",
@@ -15,4 +15,3 @@ setup(
 for i in os.listdir('.'):
     if(i.endswith('.c')):
         os.remove(i)
-
